@@ -1,6 +1,6 @@
 import unittest
 
-from unittest import TestCase, mock
+from unittest import TestCase, mock, main
 
 from aws.ec2 import *
 from aws.region import *
@@ -606,7 +606,6 @@ class TestConfiguration(TestCase):
         self.assertFalse(get_targets_in_group(group_name = 'asdf'))
         self.assertFalse(get_targets_in_group(group_arn = 'asdf'))
 
-
     def test_add_target(self):
         set_current_vpcid(get_vpc(name = 'unit-rancher-vpc'))
         tg = get_target_group(name='unit-worker-tg')
@@ -616,6 +615,7 @@ class TestConfiguration(TestCase):
         add_target(target_name = 'unit-bastion', group_name = 'unit-worker-tg')
         target_list = get_targets_in_group(group_name = 'unit-worker-tg')
         self.assertEquals(1, len(target_list))
+        get_elbv2().deregister_targets(TargetGroupArn=tg['TargetGroupArn'], Targets=[{'Id': target['InstanceId']}])
 
     ###########################################################################
     # Database Clusters & Instances
@@ -725,3 +725,7 @@ class TestConfiguration(TestCase):
 
         finally:
             pass
+
+
+if __name__ == "__main__":
+    main()
\ No newline at end of file
